.. wasiliana documentation master file, created by
   sphinx-quickstart on Fri, Jan 22 00:06:37 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to docrepo's documentation!
===================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   QuickStart <contents.rst>
   API Reference <api.rst>



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`